﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2013 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.Windows.Forms;
using HeuristicLab.Core.Views;
using HeuristicLab.MainForm;

namespace HeuristicLab.DataPreprocessing.Views {

  [View("Histogram View")]
  [Content(typeof(HistogramContent), false)]
  public partial class HistogramView : ItemView {
    public HistogramView() {
      InitializeComponent();
    }

    public new HistogramContent Content {
      get { return (HistogramContent)base.Content; }
      set { base.Content = value; }
    }

    protected override void OnContentChanged() {
      base.OnContentChanged();
      if (Content != null) {
        InitDataTable();
        InitVariablesListBox();
      }
    }

    private void InitVariablesListBox() {
      IHistogramLogic logic = Content.HistogramLogic;

      foreach (var variableName in logic.GetVariableNames()) {
        variablesListBox.Items.Add(variableName, true);
      }
    }

    private void InitDataTable() {
      IHistogramLogic logic = Content.HistogramLogic;
      viewHost.Content = logic.GetDataTable();
    }

    private void variablesListBox_ItemCheck(object sender, ItemCheckEventArgs e) {
      string item = variablesListBox.Items[e.Index] as string;

      if (e.NewValue == CheckState.Checked && !Content.HistogramLogic.VariableIsDisplayed(item))
        Content.HistogramLogic.AddVariable(item);
      else if (e.NewValue == CheckState.Unchecked && Content.HistogramLogic.VariableIsDisplayed(item))
        Content.HistogramLogic.RemoveVariable(item);
    }
  }
}





